Property Index
$#! · 0-9 · A · B · C · D · E · F · G · H · I · J · K · L · M · N · O · P · Q · R · S · T · U · V · W · X · Y · Z

D |
| dashPattern DashedHorizontalLine DashedVerticalLine
| data, jqPlot
| dataLabelCenterOn, $.jqplot.PieRenderer
| dataLabelFormatString $.jqplot.DonutRenderer$.jqplot.FunnelRenderer$.jqplot.PieRenderer
| dataLabelNudge $.jqplot.DonutRenderer$.jqplot.PieRenderer
| dataLabelPositionFactor $.jqplot.DonutRenderer$.jqplot.PieRenderer
| dataLabels $.jqplot.DonutRenderer$.jqplot.FunnelRenderer$.jqplot.PieRenderer
| dataLabelThreshold $.jqplot.DonutRenderer$.jqplot.FunnelRenderer$.jqplot.PieRenderer
| dataRenderer, jqPlot
| dataRendererOptions, jqPlot
| dblClickReset, $.jqplot.Cursor
| defaultAxisStart, jqPlot
| depth, $.jqplot.shadowRenderer
| diameter $.jqplot.DonutRenderer$.jqplot.MeterGaugeRenderer$.jqplot.PieRenderer
| disableIEFading
| disableStack, Series
| downBodyColor, $.jqplot.OHLCRenderer
| drawBaseline Global$.jqplot.DateAxisRenderer$.jqplot.LinearAxisRenderer$.jqplot.LogAxisRenderer
| drawBorder, Grid
| drawGridlines, Grid
| drawMajorGridlines, Axis
| drawMajorTickMarks, Axis
| drawMinorGridlines, Axis
| drawMinorTickMarks, Axis
E |
| edgeTolerance, $.jqplot.PointLabels
| enableFontSupport $.jqplot.CanvasAxisLabelRenderer$.jqplot.CanvasAxisTickRenderer
| escapeHtml $.jqplot.BlockRenderer$.jqplot.BubbleRenderer Legend Title
| escapeHTML $.jqplot.AxisLabelRenderer$.jqplot.AxisTickRenderer$.jqplot.PointLabels
F |
| fadeTooltip $.jqplot.CanvasOverlay$.jqplot.Highlighter
| fill Global$.jqplot.DonutRenderer$.jqplot.FunnelRenderer$.jqplot.LineRenderer$.jqplot.PieRenderer$.jqplot.shadowRenderer$.jqplot.shapeRenderer Series
| fillAlpha, Series
| fillAndStroke, Series
| fillAxis, Series
| fillBetween, jqPlot
| fillColor $.jqplot.LineRenderer Series
| fillDownBody, $.jqplot.OHLCRenderer
| fillRect, $.jqplot.shapeRenderer
| fillStyle, $.jqplot.shapeRenderer
| fillToValue, Series
| fillToZero, Series
| fillUpBody, $.jqplot.OHLCRenderer
| followMouse, $.jqplot.Cursor
| fontFamily $.jqplot.AxisTickRenderer$.jqplot.CanvasAxisLabelRenderer$.jqplot.CanvasAxisTickRenderer Legend Title
| fontSize $.jqplot.AxisTickRenderer$.jqplot.CanvasAxisLabelRenderer$.jqplot.CanvasAxisTickRenderer jqPlot Legend Title
| fontStretch $.jqplot.CanvasAxisLabelRenderer$.jqplot.CanvasAxisTickRenderer
| fontWeight $.jqplot.CanvasAxisLabelRenderer$.jqplot.CanvasAxisTickRenderer
| forceTickAt0, $.jqplot.LinearAxisRenderer
| forceTickAt100, $.jqplot.LinearAxisRenderer
| formatString $.jqplot.AxisTickRenderer$.jqplot.CanvasAxisTickRenderer$.jqplot.Highlighter$.jqplot.PointLabels
| formatter $.jqplot.AxisTickRenderer$.jqplot.CanvasAxisTickRenderer$.jqplot.PointLabels

> dashPattern: [8,8] }

Array of line, space settings in pixels.

> dashPattern: [8,8] }

Array of line, space settings in pixels.

> this.data = []

user’s data.

> this.dataLabelCenterOn = true

True to center the data label at its position.

> this.dataLabelFormatString = null

Format string for data labels.

> this.dataLabelFormatString = null

Format string for data labels.

> this.dataLabelFormatString = null

Format string for data labels.

> this.dataLabelNudge = 0

Number of pixels to slide the label away from (+) or toward (-) the center of the pie.

> this.dataLabelNudge = 2

Number of pixels to slide the label away from (+) or toward (-) the center of the pie.

> this.dataLabelPositionFactor = 0.4

A Multiplier (0-1) of the pie radius which controls position of label on slice.

> this.dataLabelPositionFactor = 0.52

A Multiplier (0-1) of the pie radius which controls position of label on slice.

> this.dataLabels = 'percent'

Either ‘label’, ‘value’, ‘percent’ or an array of labels to place on the pie slices.

> this.dataLabels = 'percent'

Either ‘label’, ‘value’, ‘percent’ or an array of labels to place on the pie slices.

> this.dataLabels = 'percent'

Either ‘label’, ‘value’, ‘percent’ or an array of labels to place on the pie slices.

> this.dataLabelThreshold = 3

> this.dataLabelThreshold = 3

> this.dataLabelThreshold = 3

Threshhold in percentage (0-100) of pie area, below which no label will be displayed.

> this.dataRenderer

A callable which can be used to preprocess data passed into the plot.

> this.dataRendererOptions

Options that will be passed to the dataRenderer.

> this.dblClickReset = true

Will reset plot zoom if double click on plot without drag.

> this.defaultAxisStart = 1

1-D data series are internally converted into 2-D [x,y] data point arrays by jqPlot.

> this.depth = 3

how many times the shadow is stroked.

> this.diameter = null

Outer diameter of the donut, auto computed by default

> this.diameter = null

Outer diameter of the meterGauge, auto computed by default

> this.diameter = null

Outer diameter of the pie, auto computed by default

> this.disableIEFading = true

true to toggle series with a show/hide method only and not allow fading in/out.

> this.disableStack = false

true to not stack this series with other series in the plot.

> this.downBodyColor = null

Color of candlestick body on a “down” day.

> this.drawBaseline = true

True to draw the axis baseline.

> this.drawBaseline = true

True to draw the axis baseline.

> this.drawBaseline = true

True to draw the axis baseline.

> this.drawBaseline = true

True to draw the axis baseline.

> this.drawBorder = true

True to draw border around grid.

> this.drawGridlines = true

whether to draw the gridlines on the plot.

> this.drawMajorGridlines = true

True to draw gridlines for major axis ticks.

> this.drawMajorTickMarks = true

True to draw tick marks for major axis ticks.

> this.drawMinorGridlines = false

True to draw gridlines for minor ticks.

> this.drawMinorTickMarks = true

True to draw tick marks for minor ticks.

> this.edgeTolerance = -5

Number of pixels that the label must be away from an axis boundary in order to be drawn.

> this.enableFontSupport = true

true to turn on native canvas font support in Mozilla 3.5+ and Safari 4+.

> this.enableFontSupport = true

true to turn on native canvas font support in Mozilla 3.5+ and Safari 4+.

> this.escapeHtml = false

true to escape html in the box label.

> this.escapeHtml = true

True to escape html in bubble label text.

> this.escapeHtml = false

True to escape special characters with their html entity equivalents in legend text.

> this.escapeHtml = false

True to escape special characters with their html entity equivalents in title text.

> this.escapeHTML = false

true to escape HTML entities in the label.

> this.escapeHTML = false

true to escape HTML entities in the label.

> this.escapeHTML = true

true to escape html entities in the labels.
true = fade in/out tooltip, flase = show/hide tooltip

> this.fadeTooltip = true

true = fade in/out tooltip, flase = show/hide tooltip

> this.fill = true

True to fill the bars.

> this.fill = true

true or false, whether to fil the slices.

> this.fill = true

true or false, whether to fill the areas.
True to fill area between bands [default: true].

> this.fill = true

true or false, whether to fil the slices.

> this.fill = false

whether to fill the shape.

> this.fill = false

whether to fill the shape.

> this.fill = false

true or false, whether to fill under lines or in bars.

> this.fillAlpha

Alpha transparency to apply to the fill under the line.

> this.fillAndStroke = false

If true will stroke the line (with color this.color) as well as fill under it.

> this.fillAxis = 'y'

Either ‘x’ or ‘y’.

> this.fillBetween = { series1: null, series2: null, color: null, baseSeries: 0, fill: true }

Fill between 2 line series in a plot.
css color spec for filled area.

> this.fillColor

CSS color spec to use for fill under line.

> this.fillDownBody = true

true to render a “down” day (close price lower than open price) with a filled candlestick body.

> this.fillRect = false

true to draw shape as a filled rectangle.

> this.fillStyle = '#999999'

css color spec for the fill style.

> this.fillToValue = 0

fill a filled series to this value on the fill axis.

> this.fillToZero = false

true will force bar and filled series to fill toward zero on the fill Axis.

> this.fillUpBody = false

true to render an “up” day (close price greater than open price) with a filled candlestick body.

> this.followMouse = false

Tooltip follows the mouse, it is not at a fixed location.

> this.fontFamily

css spec for the font-family css attribute.

> this.fontFamily = '"Trebuchet MS", Arial, Helvetica, sans-serif'

CSS spec for the font-family css attribute.

> this.fontFamily = '"Trebuchet MS", Arial, Helvetica, sans-serif'

css spec for the font-family css attribute.

> this.fontFamily

css font-family spec for the legend text.

> this.fontFamily

css font-family spec for the text.

> this.fontSize

css spec for the font-size css attribute.

> this.fontSize = '11pt'

CSS spec for font size.

> this.fontSize = '10pt'

CSS spec for font size.

> this.fontSize

css spec for the font-size attribute.

> this.fontSize

css font-size spec for the legend text.

> this.fontSize

css font-size spec for the text.

> this.fontStretch = 1.0

Multiplier to condense or expand font width.

> this.fontStretch = 1.0

Multiplier to condense or expand font width.

> this.fontWeight = 'normal'

> this.fontWeight = 'normal'

CSS spec for fontWeight

> this.forceTickAt0 = false

This will ensure that there is always a tick mark at 0.

> this.forceTickAt100 = false

This will ensure that there is always a tick mark at 100.

> this.formatString = ''

string passed to the formatter.

> this.formatString = ''

string passed to the formatter.

> this.formatString = null

alternative to tooltipFormatString will format the whole tooltip text, populating with x, y values as indicated by tooltipAxes option.

> this.formatString = ''

string passed to the formatter.

> this.formatter = $.jqplot.DefaultTickFormatter

A class of a formatter for the tick text.

> this.formatter = $.jqplot.DefaultTickFormatter

A class of a formatter for the tick text.

> this.formatter = $.jqplot.DefaultTickFormatter

A class of a formatter for the tick text.
Close